@@ -327,6 +327,24 @@ QMap<QByteArray, QByteArray> getDisplayNamesOfIds()
   return idStrMap;
 }
 
+/**
+ * Get a reduced field list without fields which are only supported by a
+ * specific tag format.
+ * @param fieldList original field list
+ * @return reduced field list.
+ */
+Frame::FieldList reducedFieldList(const Frame::FieldList& fieldList)
+{
+  Frame::FieldList reduced;
+  for (const Frame::Field& fld : fieldList) {
+    if (fld.m_id != Frame::ID_ImageFormat &&
+        fld.m_id != Frame::ID_ImageProperties) {
+      reduced.append(fld);
+    }
+  }
+  return reduced;
+}
+
 }
 
 Frame::ExtendedType::ExtendedType(const QString& name) :
@@ -877,6 +895,21 @@ const char* const* Frame::Field::getContentTypeNames()
   return contentTypeNames;
 }
 
+/**
+ * Compare two field lists in a tolerant way.
+ * This function can be used instead of the standard QList equality
+ * operator if the field lists can be from different tag formats, which
+ * may not all support the same field types.
+ * @param fl1 first field list
+ * @param fl2 second field list
+ * @return true if they are similar enough.
+ */
+bool Frame::Field::fuzzyCompareFieldLists(const QList<Field>& fl1,
+                                          const QList<Field>& fl2)
+{
+  return reducedFieldList(fl1) == reducedFieldList(fl2);
+}
+
 /**
  * Get list of available tag versions with translated description.
  * @return tag version/description pairs.
@@ -983,6 +1016,7 @@ void FrameCollection::filterDifferent(
     FrameCollection& others,
     QHash<Frame::ExtendedType, QSet<QString>>* differentValues)
 {
+  const int ALREADY_HANDLED_INDEX = INT_MIN;
   QByteArray frameData, othersData;
   auto it = begin();
   while (it != end()) {
@@ -1014,7 +1048,7 @@ void FrameCollection::filterDifferent(
           const_cast<Frame&>(*it).setDifferent();
         }
         // Mark as already handled.
-        const_cast<Frame&>(*othersIt).setIndex(-2);
+        const_cast<Frame&>(*othersIt).setIndex(ALREADY_HANDLED_INDEX);
         ++it;
         ++othersIt;
       }
@@ -1022,11 +1056,11 @@ void FrameCollection::filterDifferent(
   }
 
   // Insert frames which are in others but not in this (not marked as already
-  // handled by index -2) as different frames.
+  // handled by index ALREADY_HANDLED_INDEX) as different frames.
   for (auto othersIt = others.begin();
        othersIt != others.end();
        ++othersIt) {
-    if (othersIt->getIndex() != -2) {
+    if (othersIt->getIndex() != ALREADY_HANDLED_INDEX) {
       auto& frame = const_cast<Frame&>(*othersIt);
       frame.setIndex(-1);
       frame.setDifferent();
